@@ -40,7 +40,7 @@ bonobo_plug_atk_object_get_accessible (SpiRemoteObject *remote)
   BonoboControl            *control;
   CORBA_Environment         env;
 
-  dprintf ("Plug => SpiRemoteObjectIface->get_accessibile [%p]\n", remote);
+  debug_printf ("Plug => SpiRemoteObjectIface->get_accessibile [%p]\n", remote);
 
   g_return_val_if_fail (BONOBO_IS_PLUG_ATK_OBJECT (remote), CORBA_OBJECT_NIL);
 
@@ -108,9 +108,9 @@ bonobo_plug_atk_object_get_type (void)
 {
   static GType type = 0;
 
-  if (!type)
+  if (G_UNLIKELY (type == 0))
     {
-      static GTypeInfo typeInfo =
+      GTypeInfo typeInfo =
       {
         0,
         (GBaseInitFunc) NULL,
@@ -121,7 +121,7 @@ bonobo_plug_atk_object_get_type (void)
         (GInstanceInitFunc) bonobo_plug_atk_object_init,
       };
 
-      static const GInterfaceInfo remote_info =
+      const GInterfaceInfo remote_info =
       {
 	(GInterfaceInitFunc) bonobo_plug_atk_object_remote_init,
 	NULL,
@@ -152,7 +152,7 @@ bonobo_plug_atk_object_new (BonoboPlug *plug)
 {
   BonoboPlugAtkObject *retval;
 
-  dprintf ("bonobo_plug_atk_object_new [%p]\n", plug);
+  debug_printf ("bonobo_plug_atk_object_new [%p]\n", plug);
 
   g_return_val_if_fail (GTK_IS_PLUG (plug), NULL);
 
