@@ -46,7 +46,7 @@ struct _BonoboPlugAtkObjectClass
   GtkAccessibleClass parent;
 };
 
-GType      bonobo_plug_atk_object_get_type ();
+GType      bonobo_plug_atk_object_get_type (void);
 
 AtkObject *bonobo_plug_atk_object_new (BonoboPlug *plug);
 
