@@ -33,13 +33,13 @@ static AtkObject* bonobo_plug_atk_object_factory_create_accessible (
 static GType bonobo_plug_atk_object_factory_get_accessible_type (void);
 
 GType
-bonobo_plug_atk_object_factory_get_type ()
+bonobo_plug_atk_object_factory_get_type (void)
 {
   static GType type = 0;
 
-  if (!type) 
+  if (G_UNLIKELY (!type))
   {
-    static const GTypeInfo tinfo =
+    const GTypeInfo tinfo =
     {
       sizeof (BonoboPlugAtkObjectFactoryClass),
       (GBaseInitFunc) NULL, /* base init */
@@ -69,7 +69,7 @@ bonobo_plug_atk_object_factory_class_init (BonoboPlugAtkObjectFactoryClass *klas
 }
 
 AtkObjectFactory*
-bonobo_plug_atk_object_factory_new ()
+bonobo_plug_atk_object_factory_new (void)
 {
   GObject *factory;
 
