@@ -46,7 +46,7 @@ struct _BonoboSocketAtkObjectClass
   GtkAccessibleClass parent_class;
 };
 
-GType      bonobo_socket_atk_object_get_type ();
+GType      bonobo_socket_atk_object_get_type (void);
 
 AtkObject *bonobo_socket_atk_object_new (BonoboSocket *socket);
 
