@@ -1,7 +1,6 @@
 /*
- * gail-gnome-debug.h:
- *
- * Copyright 2002 Sun Microsystems Inc.
+ * LIBGAIL-GNOME -  Accessibility Toolkit Implementation for Bonobo
+ * Copyright 2001 Sun Microsystems Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -26,15 +25,15 @@
 
 G_BEGIN_DECLS
 
-#ifdef GAIL_GNOME_DEBUG
+#ifdef G_ENABLE_DEBUG
 
 #include <stdio.h>
 
-#define dprintf(format...) fprintf (stderr, format)
+#define debug_printf(format...) fprintf (stderr, format)
 
 #else /* G_ENABLE_DEBUG */
 
-static inline void dprintf (const char *format, ...) { };
+static inline void debug_printf (const char *format, ...) { };
 
 #endif /* G_ENABLE_DEBUG */
 
